==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/chaos/kotlin/inputs/ListSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.chaos.kotlin.inputs

import com.pulumi.azurenative.chaos.inputs.ListSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model that represents a list selector.
 * @property filter Model that represents available filter types that can be applied to a targets list.
 * @property id String of the selector ID.
 * @property targets List of Target references.
 * @property type Enum of the selector type.
 * Expected value is 'List'.
 */
public data class ListSelectorArgs(
    public val filter: Output<SimpleFilterArgs>? = null,
    public val id: Output<String>,
    public val targets: Output<List<TargetReferenceArgs>>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.chaos.inputs.ListSelectorArgs> {
    override fun toJava(): com.pulumi.azurenative.chaos.inputs.ListSelectorArgs =
        com.pulumi.azurenative.chaos.inputs.ListSelectorArgs.builder()
            .filter(filter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .id(id.applyValue({ args0 -> args0 }))
            .targets(
                targets.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSelectorArgs].
 */
@PulumiTagMarker
public class ListSelectorArgsBuilder internal constructor() {
    private var filter: Output<SimpleFilterArgs>? = null

    private var id: Output<String>? = null

    private var targets: Output<List<TargetReferenceArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("kurukhcqitjxgymg")
    public suspend fun filter(`value`: Output<SimpleFilterArgs>) {
        this.filter = value
    }

    /**
     * @param value String of the selector ID.
     */
    @JvmName("rlrfyaevxljfgbgo")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value List of Target references.
     */
    @JvmName("hsllxvduydsktaus")
    public suspend fun targets(`value`: Output<List<TargetReferenceArgs>>) {
        this.targets = value
    }

    @JvmName("acllqfoxndxqtyoe")
    public suspend fun targets(vararg values: Output<TargetReferenceArgs>) {
        this.targets = Output.all(values.asList())
    }

    /**
     * @param values List of Target references.
     */
    @JvmName("kmdqdrdacnqkknjj")
    public suspend fun targets(values: List<Output<TargetReferenceArgs>>) {
        this.targets = Output.all(values)
    }

    /**
     * @param value Enum of the selector type.
     * Expected value is 'List'.
     */
    @JvmName("rpgskdjkuddbykmg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("jgttvxgewggoapdn")
    public suspend fun filter(`value`: SimpleFilterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filter = mapped
    }

    /**
     * @param argument Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("acfqdlmruulpyxiw")
    public suspend fun filter(argument: suspend SimpleFilterArgsBuilder.() -> Unit) {
        val toBeMapped = SimpleFilterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.filter = mapped
    }

    /**
     * @param value String of the selector ID.
     */
    @JvmName("tocttitvherneiab")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value List of Target references.
     */
    @JvmName("wtcjbadcoolvrwvg")
    public suspend fun targets(`value`: List<TargetReferenceArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("prakhymhoqopkace")
    public suspend fun targets(argument: List<suspend TargetReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TargetReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("gjyagkotwciohatg")
    public suspend fun targets(vararg argument: suspend TargetReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TargetReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("ctogegtfwxykqanj")
    public suspend fun targets(argument: suspend TargetReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TargetReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param values List of Target references.
     */
    @JvmName("sxxtsrmfrqhniwat")
    public suspend fun targets(vararg values: TargetReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targets = mapped
    }

    /**
     * @param value Enum of the selector type.
     * Expected value is 'List'.
     */
    @JvmName("xbsckgvpxkpwdsvd")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ListSelectorArgs = ListSelectorArgs(
        filter = filter,
        id = id ?: throw PulumiNullFieldException("id"),
        targets = targets ?: throw PulumiNullFieldException("targets"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/chaos/kotlin/inputs/ListSelectorArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.chaos.kotlin.inputs

import com.pulumi.azurenative.chaos.inputs.ListSelectorArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model that represents a list selector.
 * @property filter Model that represents available filter types that can be applied to a targets list.
 * @property id String of the selector ID.
 * @property targets List of Target references.
 * @property type Enum of the selector type.
 * Expected value is 'List'.
 */
public data class ListSelectorArgs(
    public val filter: Output<SimpleFilterArgs>? = null,
    public val id: Output<String>,
    public val targets: Output<List<TargetReferenceArgs>>,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.chaos.inputs.ListSelectorArgs> {
    override fun toJava(): com.pulumi.azurenative.chaos.inputs.ListSelectorArgs =
        com.pulumi.azurenative.chaos.inputs.ListSelectorArgs.builder()
            .filter(filter?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .id(id.applyValue({ args0 -> args0 }))
            .targets(
                targets.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ListSelectorArgs].
 */
@PulumiTagMarker
public class ListSelectorArgsBuilder internal constructor() {
    private var filter: Output<SimpleFilterArgs>? = null

    private var id: Output<String>? = null

    private var targets: Output<List<TargetReferenceArgs>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("xpvrcfoqjqvqxsfm")
    public suspend fun filter(`value`: Output<SimpleFilterArgs>) {
        this.filter = value
    }

    /**
     * @param value String of the selector ID.
     */
    @JvmName("dcuocgmwftldtlrw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value List of Target references.
     */
    @JvmName("dsotejmigyhlpeem")
    public suspend fun targets(`value`: Output<List<TargetReferenceArgs>>) {
        this.targets = value
    }

    @JvmName("vqqpcosinrmnqlmp")
    public suspend fun targets(vararg values: Output<TargetReferenceArgs>) {
        this.targets = Output.all(values.asList())
    }

    /**
     * @param values List of Target references.
     */
    @JvmName("scprsciuadpjdxmb")
    public suspend fun targets(values: List<Output<TargetReferenceArgs>>) {
        this.targets = Output.all(values)
    }

    /**
     * @param value Enum of the selector type.
     * Expected value is 'List'.
     */
    @JvmName("udvvwrktkyxfoycx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("qocmdgfsrbwgcyds")
    public suspend fun filter(`value`: SimpleFilterArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filter = mapped
    }

    /**
     * @param argument Model that represents available filter types that can be applied to a targets list.
     */
    @JvmName("biarykmafeidkmgj")
    public suspend fun filter(argument: suspend SimpleFilterArgsBuilder.() -> Unit) {
        val toBeMapped = SimpleFilterArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.filter = mapped
    }

    /**
     * @param value String of the selector ID.
     */
    @JvmName("uwosrfgxsjskyfna")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value List of Target references.
     */
    @JvmName("kpoaolaxahexqmhd")
    public suspend fun targets(`value`: List<TargetReferenceArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("vppnhacnomxjrsai")
    public suspend fun targets(argument: List<suspend TargetReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TargetReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("ykglepwolkujtikh")
    public suspend fun targets(vararg argument: suspend TargetReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            TargetReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param argument List of Target references.
     */
    @JvmName("kyyqcboojxurnjuf")
    public suspend fun targets(argument: suspend TargetReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TargetReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.targets = mapped
    }

    /**
     * @param values List of Target references.
     */
    @JvmName("otjvgcrnkdgifmin")
    public suspend fun targets(vararg values: TargetReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.targets = mapped
    }

    /**
     * @param value Enum of the selector type.
     * Expected value is 'List'.
     */
    @JvmName("olwjnxjvdtgnvnok")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ListSelectorArgs = ListSelectorArgs(
        filter = filter,
        id = id ?: throw PulumiNullFieldException("id"),
        targets = targets ?: throw PulumiNullFieldException("targets"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
